==> img0ch-2.1.10.zip: img0ch/_template/zeromin2/log_load_thread.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs if:BBS ?><?cs include:"zeromin2/menu_bbs.cs" ?><?cs else ?><?cs include:"zeromin2/menu.cs" ?><?cs /if ?>

<div id="sidebar">
  <div>
    <p class="title"></p>
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">エラーログ閲覧</a><br />
    <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_user&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ユーザー行動履歴閲覧</a><br />
  </div>
</div>

<div id="main">

<form id="logThreadContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
<?cs if:BBS ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
<?cs /if ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ログ</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッド作成ログ閲覧</a>
</div>

<h1>スレッド作成ログ閲覧</h1>

<?cs if:Code0 ?>
<?cs if:Done_log_load_thread ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
jQuery(function(){
Zeromin2.addStyleSheet("<?cs var:html_escape(StaticURI) ?>/css/domTT.css");
});
function lookup( ip, element, event ) {
    Zeromin2.lookup(
        jQuery("form#logThreadContainerForm").get(0), ip, element, event );
}
//]]>
</script>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domLib.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domTT.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>

<p>
スレッド作成ログを表示しています。<br />
<a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=download_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;item=<?cs var:html_escape(Total) ?>&amp;offset=1&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">CSV形式でダウンロード</a>することが出来ます。<br />
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
  <tr>
    <th>IPアドレス</th>
    <th>IPグループ番号</th>
    <th>時刻</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
  <tr>
    <td><a href="javascript:void(0)" onclick="lookup( '<?cs var:html_escape(item.ip) ?>', this, event )"><?cs var:html_escape(item.ip) ?></a></td>
    <td><?cs var:html_escape(item.ip_group) ?></td>
    <td><?cs var:html_escape(item.atime) ?></td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="log" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="load_thread" />
<input type="hidden" name="NG" value="load_thread" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-2.1.18.zip: img0ch/_template/zeromin2/log_load_thread.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs if:BBS ?><?cs include:"zeromin2/menu_bbs.cs" ?><?cs else ?><?cs include:"zeromin2/menu.cs" ?><?cs /if ?>

<?cs include:"zeromin2/log_side_menu.cs" ?>

<div id="main">

<form id="logThreadContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
<?cs if:BBS ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
<?cs /if ?>
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ログ</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッド作成ログ閲覧</a>
</div>

<h1>スレッド作成ログ閲覧</h1>

<?cs if:Code0 ?>
<?cs if:Done_log_load_thread ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs /if ?>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
jQuery(function(){
Zeromin2.addStyleSheet("<?cs var:html_escape(StaticURI) ?>/css/domTT.css");
});
function lookup( ip, element, event ) {
    Zeromin2.lookup(
        jQuery("form#logThreadContainerForm").get(0), ip, element, event );
}
//]]>
</script>

<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domLib.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domTT.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>

<p>
スレッド作成ログを表示しています。<br />
<a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=download_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;item=<?cs var:html_escape(Total) ?>&amp;offset=1&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">CSV形式でダウンロード</a>することが出来ます。<br />
</p>

<p>
ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_thread&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
  <tr>
    <th>IPアドレス</th>
    <th>IPグループ番号</th>
    <th>時刻</th>
  </tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
  <tr>
    <td><a href="javascript:void(0)" onclick="lookup( '<?cs var:html_escape(item.ip) ?>', this, event )"><?cs var:html_escape(item.ip) ?></a></td>
    <td><?cs var:html_escape(item.ip_group) ?></td>
    <td><?cs var:html_escape(item.atime) ?></td>
  </tr>
  <?cs /each ?>
  </tbody>
</table>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="log" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="load_thread" />
<input type="hidden" name="NG" value="load_thread" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
